==> django-froala-editor-0.8.0.tar.gz: django-froala-editor-0.8.0/froala_editor/static/froala_editor/js/langs/pt_br.js <==
/**
 * Portuguese spoken in Brazil
 */

$.Editable.LANGS['pt_br'] = {
  translation: {
    "Bold": "Negrito",
    "Italic": "It\u00e1lico",
    "Underline": "Sublinhar",
    "Strikethrough": "Riscar",
    "Font Size": "Tamanho",
    "Color": "Cor",
    "Background Color": "Cor do fundo",
    "Text Color": "Cor do texto",
    "Format Block": "Formatos",
    "Normal": "Normal",
    "Paragraph": "Par\u00e1grafo",
    "Code": "C\u00f3digo",
    "Quote": "Aspas",
    "Heading 1": "Cabe\u00e7alho 1",
    "Heading 2": "Cabe\u00e7alho 2",
    "Heading 3": "Cabe\u00e7alho 3",
    "Heading 4": "Cabe\u00e7alho 4",
    "Heading 5": "Cabe\u00e7alho 5",
    "Heading 6": "Cabe\u00e7alho 6",
    "Alignment": "Alinhamento",
    "Align Left": "Alinhar \u00e0 esquerda",
    "Align Center": "Centralizar",
    "Align Right": "Alinhar \u00e0 direita",
    "Justify": "Justificar",
    "Numbered List": "Lista ordenada",
    "Bulleted List": "Lista n\u00e3o ordenada",
    "Indent Less": "Diminuir recuo",
    "Indent More": "Aumentar recuo",
    "Select All": "Selecionar tudo",
    "Insert Link": "Inserir link",
    "Insert Image": "Inserir imagem",
    "Insert Video": "Inserir v\u00eddeo",
    "Undo": "Desfazer",
    "Redo": "Refazer",
    "Show HTML": "Mostrar HTML",
    "Float Left": "Esquerdo",
    "Float None": "Nenhum",
    "Float Right": "Direita",
    "Replace Image": "Substituir imagem",
    "Remove Image": "Remover imagem",
    "Title": "T\u00edtulo",
    "Insert image": "Inserir imagem",
    "Drop image": "Largue imagem",
    "or click": "ou clique em",
    "Enter URL": "Digite a URL",
    "Please wait!": "Por favor, aguarde!",
    "Are you sure? Image will be deleted.": "Voc\u00ea tem certeza? Imagem ser\u00e1 apagada.",
    "UNLINK": "Remover link",
    "Open in new tab": "Abrir em uma nova aba",
    "Type something": "Digite algo",
    "Cancel": "Cancelar",
    "OK": "Ok",
    "Manage images": "Manejar imagens",
    "Delete": "Apagar",
    "Font Family": "Fonte",
    "Insert Horizontal Line": "Inserir linha horizontal"
  },
  direction: "ltr"
};

==> django-froala-editor-0.8.5.tar.gz: django-froala-editor-0.8.5/froala_editor/static/froala_editor/js/langs/pt_br.js <==
/*!
 * froala_editor v1.1.6 (http://editor.froala.com)
 * Copyright 2014-2014 Froala
 */

/**
 * Portuguese spoken in Brazil
 */

$.Editable.LANGS['pt_br'] = {
  translation: {
    "Bold": "Negrito",
    "Italic": "It\u00e1lico",
    "Underline": "Sublinhar",
    "Strikethrough": "Riscar",
    "Font Size": "Tamanho",
    "Color": "Cor",
    "Background Color": "Cor do fundo",
    "Text Color": "Cor do texto",
    "Format Block": "Formatos",
    "Normal": "Normal",
    "Paragraph": "Par\u00e1grafo",
    "Code": "C\u00f3digo",
    "Quote": "Aspas",
    "Heading 1": "Cabe\u00e7alho 1",
    "Heading 2": "Cabe\u00e7alho 2",
    "Heading 3": "Cabe\u00e7alho 3",
    "Heading 4": "Cabe\u00e7alho 4",
    "Heading 5": "Cabe\u00e7alho 5",
    "Heading 6": "Cabe\u00e7alho 6",
    "Alignment": "Alinhamento",
    "Align Left": "Alinhar \u00e0 esquerda",
    "Align Center": "Centralizar",
    "Align Right": "Alinhar \u00e0 direita",
    "Justify": "Justificar",
    "Numbered List": "Lista ordenada",
    "Bulleted List": "Lista n\u00e3o ordenada",
    "Indent Less": "Diminuir recuo",
    "Indent More": "Aumentar recuo",
    "Select All": "Selecionar tudo",
    "Insert Link": "Inserir link",
    "Insert Image": "Inserir imagem",
    "Insert Video": "Inserir v\u00eddeo",
    "Undo": "Desfazer",
    "Redo": "Refazer",
    "Show HTML": "Mostrar HTML",
    "Float Left": "Esquerdo",
    "Float None": "Nenhum",
    "Float Right": "Direita",
    "Replace Image": "Substituir imagem",
    "Remove Image": "Remover imagem",
    "Title": "T\u00edtulo",
    "Insert image": "Inserir imagem",
    "Drop image": "Largue imagem",
    "or click": "ou clique em",
    "Enter URL": "Digite a URL",
    "Please wait!": "Por favor, aguarde!",
    "Are you sure? Image will be deleted.": "Voc\u00ea tem certeza? Imagem ser\u00e1 apagada.",
    "UNLINK": "Remover link",
    "Open in new tab": "Abrir em uma nova aba",
    "Type something": "Digite algo",
    "Cancel": "Cancelar",
    "OK": "Ok",
    "Manage images": "Manejar imagens",
    "Delete": "Apagar",
    "Font Family": "Fonte",
    "Insert Horizontal Line": "Inserir linha horizontal",
    "Table": "Tabela",
    "Insert table": "Inserir tabela",
    "Cell": "C\u00e9lula",
    "Row": "Linha",
    "Column": "Coluna",
    "Delete table": "Excluir tabela",
    "Insert cell before": "Inserir c\u00e9lula antes",
    "Insert cell after": "Inserir c\u00e9lula depois",
    "Delete cell": "Excluir celular",
    "Merge cells": "Agrupar c\u00e9lulas",
    "Horizontal split": "Divis\u00e3o horizontal",
    "Vertical split": "Divis\u00e3o vertical",
    "Insert row above": "Inserir linha antes",
    "Insert row below": "Inserir linha depois",
    "Delete row": "Excluir linha",
    "Insert column before": "Inserir coluna antes",
    "Insert column after": "Inserir coluna depois",
    "Delete column": "Excluir coluna"
  },
  direction: "ltr"
};
